@@ -2,20 +2,23 @@
 # Demonstration code to use the ML-experiment framework
 
 import sys
+
 sys.path.append("./src")
-import experiment as exp
 import configparser
+
+import experiment as exp
 from util import Util
 
+
 def main(config_file):
     # load one configuration per experiment
     config = configparser.ConfigParser()
     config.read(config_file)
-    
+
     # create a new experiment
     expr = exp.Experiment(config)
     util = Util()
-    util.debug(f'running {expr.name}')
+    util.debug(f"running {expr.name}")
 
     # load the data
     expr.load_datasets()
@@ -32,13 +35,14 @@ def main(config_file):
     # run the experiment
     expr.run()
 
-    print('DONE')
+    print("DONE")
+
 
 if __name__ == "__main__":
-#    main('./demos/exp_danish_local.ini')
-#    main('./demos/exp_emodb_wav2vec.ini')
-#    main('./demos/exp_cross_wav2vec1pager.ini')
-#    main('./demos/exp_emodb_local.ini')
-    main('./demos/exp_cross_local.ini')
+    #    main('./demos/exp_danish_local.ini')
+    #    main('./demos/exp_emodb_wav2vec.ini')
+    #    main('./demos/exp_cross_wav2vec1pager.ini')
+    #    main('./demos/exp_emodb_local.ini')
+    main("./demos/exp_cross_local.ini")
 #    main('./demos/exp_bdtgfir pul_local.ini')
 #    main(sys.argv[1]) # use this if you want to state the config file path on command line
