@@ -300,43 +300,34 @@ class Experiment:
             else:
                 if not self.test_empty:
                     if self.df_test.is_labeled:
-                        test_cats = self.df_test[self.target].unique()
+                        # get printable string of categories and their counts
+                        test_cats = self.df_test[self.target].value_counts().to_string()
                     else:
                         # if there is no target, copy a dummy label
                         self.df_test = self._add_random_target(self.df_test).astype(
                             "str"
                         )
                 if not self.train_empty:
-                    train_cats = self.df_train[self.target].unique()
+                    train_cats = self.df_train[self.target].value_counts().to_string()
                 if self.split3 and not self.dev_empty:
-                    dev_cats = self.df_dev[self.target].unique()
+                    dev_cats = self.df_dev[self.target].value_counts().to_string()
             # encode the labels as numbers
             self.label_encoder = LabelEncoder()
             glob_conf.set_label_encoder(self.label_encoder)
             if not self.train_empty:
-                if isinstance(train_cats, np.ndarray):
-                    self.util.debug(f"Categories train (nd.array): {train_cats}")
-                else:
-                    self.util.debug(f"Categories train (list): {list(train_cats)}")
-
+                self.util.debug(f"Categories train: {train_cats}")
                 self.df_train[self.target] = self.label_encoder.fit_transform(
                     self.df_train[self.target]
                 )
             if not self.test_empty:
                 if self.df_test.is_labeled:
-                    if isinstance(test_cats, np.ndarray):
-                        self.util.debug(f"Categories test (nd.array): {test_cats}")
-                    else:
-                        self.util.debug(f"Categories test (list): {list(test_cats)}")
+                    self.util.debug(f"Categories test: {test_cats}")
                 if not self.train_empty:
                     self.df_test[self.target] = self.label_encoder.transform(
                         self.df_test[self.target]
                     )
             if self.split3 and not self.dev_empty:
-                if isinstance(dev_cats, np.ndarray):
-                    self.util.debug(f"Categories dev (nd.array): {dev_cats}")
-                else:
-                    self.util.debug(f"Categories dev (list): {list(dev_cats)}")
+                self.util.debug(f"Categories dev: {dev_cats}")
                 if not self.train_empty:
                     self.df_dev[self.target] = self.label_encoder.transform(
                         self.df_dev[self.target]
@@ -574,6 +565,11 @@ class Experiment:
 
                 predictor = TextPredictor(df, self.util)
                 df = predictor.predict(sample_selection)
+            elif target == "translation":
+                from nkululeko.autopredict.ap_translate import TextTranslator
+
+                predictor = TextTranslator(df, self.util)
+                df = predictor.predict(sample_selection)
             elif target == "arousal":
                 from nkululeko.autopredict.ap_arousal import ArousalPredictor
 
@@ -677,7 +673,7 @@ class Experiment:
             feat_analyser.analyse()
 
         # check if a scatterplot should be done
-        scatter_var = eval(self.util.config_val("EXPL", "scatter", "False"))
+        list_of_dimreds = eval(self.util.config_val("EXPL", "scatter", "False"))
 
         # Priority: use [EXPL][scatter.target] if available, otherwise use [DATA][target] value
         if hasattr(self, "target") and self.target != "none":
@@ -697,14 +693,14 @@ class Experiment:
             self.util.debug(
                 f"scatter.target from [EXPL][scatter.target]: {scatter_target}"
             )
-        if scatter_var:
-            scatters = ast.literal_eval(scatter_target)
+        if list_of_dimreds:
+            dimreds = list_of_dimreds
             scat_targets = ast.literal_eval(scatter_target)
             plots = Plots()
             for scat_target in scat_targets:
                 if self.util.is_categorical(df_labels[scat_target]):
-                    for scatter in scatters:
-                        plots.scatter_plot(df_feats, df_labels, scat_target, scatter)
+                    for dimred in dimreds:
+                        plots.scatter_plot(df_feats, df_labels, scat_target, dimred)
                 else:
                     self.util.debug(
                         f"{self.name}: binning continuous variable to categories"
@@ -713,9 +709,9 @@ class Experiment:
                         df_labels[scat_target]
                     )
                     df_labels[f"{scat_target}_bins"] = cat_vals.values
-                    for scatter in scatters:
+                    for dimred in dimreds:
                         plots.scatter_plot(
-                            df_feats, df_labels, f"{scat_target}_bins", scatter
+                            df_feats, df_labels, f"{scat_target}_bins", dimred
                         )
 
         # check if t-SNE plot should be generated
