@@ -1,36 +1,32 @@
 # export.py
 # export the loaded training and test sets to it's own folder
 
-import os
-import pandas as pd
-import configparser
-import audeer
 import argparse
-import audiofile
-from nkululeko.experiment import Experiment
-from nkululeko.utils.util import Util
-from nkululeko.constants import VERSION
+import configparser
+import os
 import shutil
 
+import audeer
+import audiofile
+import pandas as pd
 
-def main(src_dir):
+from nkululeko.constants import VERSION
+from nkululeko.experiment import Experiment
+from nkululeko.utils.util import Util
+
+
+def main():
     parser = argparse.ArgumentParser(description="Call the nkululeko framework.")
     parser.add_argument("--config", default="exp.ini", help="The base configuration")
     args = parser.parse_args()
-    if args.config is not None:
-        config_file = args.config
-    else:
-        config_file = f"{src_dir}/exp.ini"
+    config_file = args.config if args.config is not None else "exp.ini"
 
-    # test if the configuration file exists
     if not os.path.isfile(config_file):
         print(f"ERROR: no such file: {config_file}")
         exit()
 
-    # load one configuration per experiment
     config = configparser.ConfigParser()
     config.read(config_file)
-    # create a new experiment
     expr = Experiment(config)
     util = Util("export")
     util.debug(
@@ -120,5 +116,4 @@ def main(src_dir):
 
 
 if __name__ == "__main__":
-    cwd = os.path.dirname(os.path.abspath(__file__))
-    main(cwd)  # use this if you want to state the config file path on command line
+    main()
