@@ -1,15 +1,18 @@
 # feats_agender.py
 
-from nkululeko.feat_extract.featureset import Featureset
 import os
+
 # import pandas as pd
 import audeer
-import nkululeko.glob_conf as glob_conf
+import audinterface
 import audonnx
 import numpy as np
-import audinterface
 import torch
 
+import nkululeko.glob_conf as glob_conf
+from nkululeko.feat_extract.featureset import Featureset
+
+
 class AgenderSet(Featureset):
     """
     Embeddings from the wav2vec2. based model finetuned on agender data, described in the paper
@@ -30,13 +33,12 @@ class AgenderSet(Featureset):
         if not os.path.isdir(model_root):
             cache_root = audeer.mkdir("cache")
             model_root = audeer.mkdir(model_root)
-            archive_path = audeer.download_url(
-                model_url, cache_root, verbose=True)
+            archive_path = audeer.download_url(model_url, cache_root, verbose=True)
             audeer.extract_archive(archive_path, model_root)
         cuda = "cuda" if torch.cuda.is_available() else "cpu"
         device = self.util.config_val("MODEL", "device", cuda)
         self.model = audonnx.load(model_root, device=device)
-        self.util.debug(f"initialized agender model")
+        self.util.debug("initialized agender model")
         self.model_loaded = True
 
     def extract(self):
@@ -62,7 +64,7 @@ class AgenderSet(Featureset):
                 },
                 sampling_rate=16000,
                 resample=True,
-                num_workers=5,
+                num_workers=self.n_jobs,
                 verbose=True,
             )
             self.df = hidden_states.process_index(self.data_df.index)
