@@ -1,14 +1,14 @@
 # feats_clap.py
 
-from nkululeko.utils.util import Util
-from nkululeko.feat_extract.featureset import Featureset
 import os
+
+import audiofile
+import laion_clap
 import pandas as pd
 from tqdm import tqdm
-import os
+
 import nkululeko.glob_conf as glob_conf
-import laion_clap
-import audiofile
+from nkululeko.feat_extract.featureset import Featureset
 
 
 class ClapSet(Featureset):
@@ -26,21 +26,19 @@ class ClapSet(Featureset):
         self.util.debug("loading clap model...")
         self.model = laion_clap.CLAP_Module(enable_fusion=False)
         self.model.load_ckpt()  # download the default pretrained checkpoint.
-        print(f"loaded clap model")
+        print("loaded clap model")
 
     def extract(self):
         """Extract the features or load them from disk if present."""
         store = self.util.get_path("store")
         store_format = self.util.config_val("FEATS", "store_format", "pkl")
         storage = f"{store}{self.name}.{store_format}"
-        extract = self.util.config_val(
-            "FEATS", "needs_feature_extraction", False)
+        extract = self.util.config_val("FEATS", "needs_feature_extraction", False)
         no_reuse = eval(self.util.config_val("FEATS", "no_reuse", "False"))
         if extract or no_reuse or not os.path.isfile(storage):
             if not self.model_initialized:
                 self.init_model()
-            self.util.debug(
-                "extracting clap embeddings, this might take a while...")
+            self.util.debug("extracting clap embeddings, this might take a while...")
             emb_series = pd.Series(index=self.data_df.index, dtype=object)
             length = len(self.data_df.index)
             for idx, (file, start, end) in enumerate(
@@ -54,8 +52,7 @@ class ClapSet(Featureset):
                 )
                 emb = self.get_embeddings(signal, sampling_rate)
                 emb_series[idx] = emb
-            self.df = pd.DataFrame(
-                emb_series.values.tolist(), index=self.data_df.index)
+            self.df = pd.DataFrame(emb_series.values.tolist(), index=self.data_df.index)
             self.util.write_store(self.df, storage, store_format)
             try:
                 glob_conf.config["DATA"]["needs_feature_extraction"] = "false"
