@@ -5,10 +5,9 @@ import random
 
 import numpy as np
 import pandas as pd
-from sklearn.model_selection import GridSearchCV
-from sklearn.model_selection import LeaveOneGroupOut
-from sklearn.model_selection import StratifiedKFold
 import sklearn.utils
+from joblib import parallel_backend
+from sklearn.model_selection import GridSearchCV, LeaveOneGroupOut, StratifiedKFold
 
 import nkululeko.glob_conf as glob_conf
 from nkululeko.reporting.reporter import Reporter
@@ -34,6 +33,7 @@ class Model:
         self.epoch = 0
         self.logo = self.util.config_val("MODEL", "logo", False)
         self.xfoldx = self.util.config_val("MODEL", "k_fold_cross", False)
+        self.n_jobs = int(self.util.config_val("MODEL", "n_jobs", "8"))
 
     def set_model_type(self, type):
         self.model_type = type
@@ -75,7 +75,8 @@ class Model:
         ):
             train_x = feats.iloc[train_index].to_numpy()
             train_y = targets[train_index]
-            self.clf.fit(train_x, train_y)
+            with parallel_backend("threading", n_jobs=self.n_jobs):
+                self.clf.fit(train_x, train_y)
             truth_x = feats.iloc[test_index].to_numpy()
             truth_y = targets[test_index]
             predict_y = self.clf.predict(truth_x)
@@ -116,7 +117,7 @@ class Model:
         # get unique list of speakers
         speakers = annos["speaker"].unique()
         # check for folds columns
-        if not "fold" in annos.columns:
+        if "fold" not in annos.columns:
             self.util.debug(f"creating random folds for {logo} groups")
             # create a random dictionary of groups
             sdict = {}
@@ -141,7 +142,8 @@ class Model:
         ):
             train_x = feats.iloc[train_index].to_numpy()
             train_y = targets.iloc[train_index]
-            self.clf.fit(train_x, train_y)
+            with parallel_backend("threading", n_jobs=self.n_jobs):
+                self.clf.fit(train_x, train_y)
 
             truth_x = feats.iloc[test_index].to_numpy()
             truth_y = targets.iloc[test_index]
@@ -169,9 +171,10 @@ class Model:
             f"LOGO: {self.logo} folds: mean {results.mean():.3f}, std:"
             f" {results.std():.3f}"
         )
+        report.print_logo(results)
 
     def train(self):
-        """Train the model"""
+        """Train the model."""
         # # first check if the model already has been trained
         # if os.path.isfile(self.store_path):
         #     self.load(self.run, self.epoch)
@@ -204,22 +207,39 @@ class Model:
             )
 
         tuning_params = self.util.config_val("MODEL", "tuning_params", False)
-        if tuning_params:
-            # tune the model meta parameters
-            tuning_params = ast.literal_eval(tuning_params)
-            tuned_params = {}
-            try:
-                scoring = glob_conf.config["MODEL"]["scoring"]
-            except KeyError:
-                self.util.error("got tuning params but no scoring")
-            for param in tuning_params:
-                values = ast.literal_eval(glob_conf.config["MODEL"][param])
-                tuned_params[param] = values
-            self.util.debug(f"tuning on {tuned_params}")
-            self.clf = GridSearchCV(
-                self.clf, tuned_params, refit=True, verbose=3, scoring=scoring
-            )
-            try:
+        with parallel_backend("threading", n_jobs=self.n_jobs):
+            if tuning_params:
+                # tune the model meta parameters
+                tuning_params = ast.literal_eval(tuning_params)
+                tuned_params = {}
+                try:
+                    scoring = glob_conf.config["MODEL"]["scoring"]
+                except KeyError:
+                    self.util.error("got tuning params but no scoring")
+                for param in tuning_params:
+                    values = ast.literal_eval(glob_conf.config["MODEL"][param])
+                    tuned_params[param] = values
+                self.util.debug(f"tuning on {tuned_params}")
+                self.clf = GridSearchCV(
+                    self.clf, tuned_params, refit=True, verbose=3, scoring=scoring
+                )
+                try:
+                    class_weight = eval(
+                        self.util.config_val("MODEL", "class_weight", "False")
+                    )
+                    if class_weight:
+                        self.util.debug("using class weight")
+                        self.clf.fit(
+                            feats,
+                            self.df_train[self.target],
+                            sample_weight=self.classes_weights,
+                        )
+                    else:
+                        self.clf.fit(feats, self.df_train[self.target])
+                except KeyError:
+                    self.clf.fit(feats, self.df_train[self.target])
+                self.util.debug(f"winner parameters: {self.clf.best_params_}")
+            else:
                 class_weight = self.util.config_val("MODEL", "class_weight", False)
                 if class_weight:
                     self.util.debug("using class weight")
@@ -229,22 +249,8 @@ class Model:
                         sample_weight=self.classes_weights,
                     )
                 else:
-                    self.clf.fit(feats, self.df_train[self.target])
-            except KeyError:
-                self.clf.fit(feats, self.df_train[self.target])
-            self.util.debug(f"winner parameters: {self.clf.best_params_}")
-        else:
-            class_weight = self.util.config_val("MODEL", "class_weight", False)
-            if class_weight:
-                self.util.debug("using class weight")
-                self.clf.fit(
-                    feats,
-                    self.df_train[self.target],
-                    sample_weight=self.classes_weights,
-                )
-            else:
-                labels = self.df_train[self.target]
-                self.clf.fit(feats, labels)
+                    labels = self.df_train[self.target]
+                    self.clf.fit(feats, labels)
 
     def get_predictions(self):
         #        predictions = self.clf.predict(self.feats_test.to_numpy())
