@@ -9,6 +9,7 @@ from scipy import stats
 import seaborn as sns
 from sklearn.manifold import TSNE
 
+import audeer
 from audmetric import concordance_cc as ccc
 
 import nkululeko.glob_conf as glob_conf
@@ -27,7 +28,12 @@ class Plots:
         self.with_ccc = eval(self.util.config_val("PLOT", "ccc", "False"))
         self.type_s = "samples"
 
-    def plot_distributions_speaker(self, df):
+    def plot_distributions_speaker(self, df: pd.DataFrame):
+        if df.empty:
+            self.util.warn(
+                "plot_distributions_speaker: empty DataFrame, nothing to plot"
+            )
+            return
         self.type_s = "speaker"
         df_speakers = pd.DataFrame()
         pd.options.mode.chained_assignment = None  # default='warn'
@@ -86,7 +92,10 @@ class Plots:
 
         self.plot_distributions(df_speakers, type_s="speakers")
 
-    def plot_distributions(self, df, type_s="samples"):
+    def plot_distributions(self, df: pd.DataFrame, type_s: str = "samples"):
+        if df.empty:
+            self.util.warn("plot_distributions: empty DataFrame, nothing to plot")
+            return
         class_label, df = self._check_binning("class_label", df)
         value_counts_conf = self.util.config_val("EXPL", "value_counts", False)
         if not isinstance(value_counts_conf, str):
@@ -218,7 +227,7 @@ class Plots:
 
     def save_plot(self, ax, caption, header, filename, type_s):
         # one up because of the runs
-        fig_dir = os.path.dirname(self.util.get_path("fig_dir"))
+        fig_dir = audeer.path(self.util.get_path("fig_dir"), "..")
         fig_plots = ax.figure
         # avoid warning
         # plt.tight_layout()
@@ -601,25 +610,54 @@ class Plots:
 
     def plot_feature(self, title, feature, label, df_labels, df_features):
         # remove fullstops in the name
-        feature_name = feature.replace(".", "-")
+        feature_name = str(feature).replace(".", "-")
         # one up because of the runs
-        fig_dir = os.path.join(self.util.get_path("fig_dir"), "..")
-        filename = os.path.join(
+        fig_dir = audeer.path(self.util.get_path("fig_dir"), "..")
+        filename = audeer.path(
             fig_dir, f"feat_dist_{title}_{feature_name}.{self.format}"
         )
+        ignore_gender = eval(self.util.config_val("EXPL", "ignore_gender", "False"))
         if self.util.is_categorical(df_labels[label]):
-            df_plot = pd.DataFrame(
-                {label: df_labels[label], feature: df_features[feature]}
-            )
             p_val = ""
-            if df_labels[label].nunique() == 2:
-                label_1 = df_labels[label].unique()[0]
-                label_2 = df_labels[label].unique()[1]
-                vals_1 = df_plot[df_plot[label] == label_1][feature].values
-                vals_2 = df_plot[df_plot[label] == label_2][feature].values
-                r_stats = stats.mannwhitneyu(vals_1, vals_2, alternative="two-sided")
-                p_val = f", Mann-Whitney p-val: {r_stats.pvalue:.3f}"
-            ax = sns.violinplot(data=df_plot, x=label, y=feature)
+            if (
+                "gender" in df_labels
+                and df_labels["gender"].notna().any()
+                and not ignore_gender
+            ):
+                # plot distribution for each gender in parallel violin plots
+                df_plot = pd.DataFrame(
+                    {
+                        label: df_labels[label],
+                        feature: df_features[feature],
+                        "gender": df_labels["gender"],
+                    }
+                )
+                if df_labels[label].nunique() == 2:
+                    label_1 = df_labels[label].unique()[0]
+                    label_2 = df_labels[label].unique()[1]
+                    vals_1 = df_plot[df_plot[label] == label_1][feature].values
+                    vals_2 = df_plot[df_plot[label] == label_2][feature].values
+                    r_stats = stats.mannwhitneyu(
+                        vals_1, vals_2, alternative="two-sided"
+                    )
+                    p_val = f", Mann-Whitney p-val: {r_stats.pvalue:.3f}"
+                ax = sns.violinplot(
+                    data=df_plot, x=label, y=feature, hue="gender", split=True
+                )
+            else:
+                df_plot = pd.DataFrame(
+                    {label: df_labels[label], feature: df_features[feature]}
+                )
+                if df_labels[label].nunique() == 2:
+                    label_1 = df_labels[label].unique()[0]
+                    label_2 = df_labels[label].unique()[1]
+                    vals_1 = df_plot[df_plot[label] == label_1][feature].values
+                    vals_2 = df_plot[df_plot[label] == label_2][feature].values
+                    r_stats = stats.mannwhitneyu(
+                        vals_1, vals_2, alternative="two-sided"
+                    )
+                    p_val = f", Mann-Whitney p-val: {r_stats.pvalue:.3f}"
+                ax = sns.violinplot(data=df_plot, x=label, y=feature)
             label = self.util.config_val("DATA", "target", "class_label")
             ax.set(title=f"{title} samples {p_val}", xlabel=label)
         else:
