@@ -1,6 +1,6 @@
 """Runmanager module.
 
-This module contains the Runmanager class which is responsible for managing the 
+This module contains the Runmanager class which is responsible for managing the
 runs of the experiment.
 """
 
@@ -22,7 +22,9 @@ class Runmanager:
     )  # The dataframes
     reports = []
 
-    def __init__(self, df_train, df_test, feats_train, feats_test):
+    def __init__(
+        self, df_train, df_test, feats_train, feats_test, dev_x=None, dev_y=None
+    ):
         """Constructor setting up the dataframes.
 
         Args:
@@ -38,11 +40,10 @@ class Runmanager:
             feats_train,
             feats_test,
         )
+        self.df_dev, self.feats_dev = dev_x, dev_y
         self.util = Util("runmanager")
         self.target = glob_conf.config["DATA"]["target"]
-        # intialize a new model
-        # model_type = glob_conf.config['MODEL']['type']
-        # self._select_model(model_type)
+        self.split3 = eval(self.util.config_val("EXP", "traindevtest", "False"))
 
     def do_runs(self):
         """Start the runs."""
@@ -50,17 +51,39 @@ class Runmanager:
         self.last_epochs = []  # keep the epoch of best result per run
         # for all runs
         for run in range(int(self.util.config_val("EXP", "runs", 1))):
-            self.util.debug(f"run {run} using model {glob_conf.config['MODEL']['type']}")
+            self.util.debug(
+                f"run {run} using model {glob_conf.config['MODEL']['type']}"
+            )
             # set the run index as global variable for reporting
             self.util.set_config_val("EXP", "run", run)
-            self.modelrunner = Modelrunner(
-                self.df_train,
-                self.df_test,
-                self.feats_train,
-                self.feats_test,
-                run,
+            if self.df_dev is not None:
+                self.modelrunner = Modelrunner(
+                    self.df_train,
+                    self.df_dev,
+                    self.feats_train,
+                    self.feats_dev,
+                    run,
+                )
+                self.reports, last_epoch = self.modelrunner.do_epochs()
+            else:
+                self.modelrunner = Modelrunner(
+                    self.df_train,
+                    self.df_test,
+                    self.feats_train,
+                    self.feats_test,
+                    run,
+                )
+                self.reports, last_epoch = self.modelrunner.do_epochs()
+
+            last_report = self.reports[-1]
+            plot_name_suggest = self.util.get_exp_name()
+            plot_name = (
+                self.util.config_val("PLOT", "name", plot_name_suggest)
+                + f"_last_{last_report.run}_{last_report.epoch:03d}"
             )
-            self.reports, last_epoch = self.modelrunner.do_epochs()
+            # finally, print out the numbers for this run
+            self.print_report(last_report, plot_name)
+
             # wrap up the run
             plot_anim_progression = self.util.config_val("PLOT", "anim_progression", 0)
             if plot_anim_progression:
@@ -80,7 +103,6 @@ class Runmanager:
                 # possibly this value has not been set
                 epoch_num = 1
             if epoch_num > 1 and plot_epoch_progression:
-                plot_name_suggest = self.util.get_exp_name()
                 plot_name = (
                     self.util.config_val("PLOT", "name", plot_name_suggest)
                     + "_epoch_progression"
@@ -89,25 +111,34 @@ class Runmanager:
                 self.reports[-1].plot_epoch_progression(self.reports, plot_name)
             # remember the best run
             best_report = self.get_best_result(self.reports)
-            plot_best_model = self.util.config_val("PLOT", "best_model", False)
-
-            if epoch_num > 1 and plot_best_model:
-                plot_name_suggest = self.util.get_exp_name()
+            plot_name = (
+                self.util.config_val("PLOT", "name", plot_name_suggest)
+                + f"_BEST-dev_{best_report.run}_{best_report.epoch:03d}"
+            )
+            # finally, print out the numbers for this run
+            # self.print_report(best_report, plot_name)
+            # remember the best run
+            # Only print if best_report is not the same as last_report
+            if best_report is not last_report:
                 plot_name = (
                     self.util.config_val("PLOT", "name", plot_name_suggest)
-                    + f"_BEST_{best_report.run}_{best_report.epoch:03d}_BEST_cnf"
+                    + f"_BEST-dev_{best_report.run}_{best_report.epoch:03d}"
                 )
-                self.util.debug(
-                    f"best result with run {best_report.run} and epoch"
-                    f" {best_report.epoch}:"
-                    f" {best_report.result.get_test_result()}"
-                )
-                self.print_model(best_report, plot_name)
-            # finally, print out the numbers for this run
-            best_report.print_results(best_report.epoch)
-            best_report.print_probabilities()
+                self.print_report(best_report, plot_name)
+
             self.best_results.append(best_report)
             self.last_epochs.append(last_epoch)
+            if self.split3:
+                best_model = self.get_best_model()
+                self.test_report = self.modelrunner.eval_specific_model(
+                    best_model, self.df_test, self.feats_test
+                )
+                self.test_report.epoch = best_report.epoch
+                plot_name = (
+                    self.util.config_val("PLOT", "name", plot_name_suggest)
+                    + f"_test_{best_report.run}_{best_report.epoch:03d}"
+                )
+                self.print_report(self.test_report, plot_name)
 
     def print_best_result_runs(self):
         """Print the best result for all runs."""
@@ -121,7 +152,7 @@ class Runmanager:
             self.util.config_val("PLOT", "name", plot_name_suggest)
             + f"_BEST_{best_report.run}_{best_report.epoch:03d}_BEST_cnf"
         )
-        self.print_model(best_report, plot_name)
+        self.print_report(best_report, plot_name)
 
     def print_given_result(self, run, epoch):
         """Print a result (confusion matrix) for a given epoch and run.
@@ -139,9 +170,9 @@ class Runmanager:
             self.util.config_val("PLOT", "name", plot_name_suggest)
             + f"_extra_{run}_{epoch:03d}_cnf"
         )
-        self.print_model(report, plot_name)
+        self.print_report(report, plot_name)
 
-    def print_model(self, reporter, plot_name):
+    def print_report(self, report, plot_name):
         """Print a confusion matrix for a special report.
 
         Args:
@@ -150,9 +181,10 @@ class Runmanager:
         """
         # self.load_model(report)
         # report = self.model.predict()
-        self.util.debug(f"plotting conf matrix to {plot_name}")
-        reporter.plot_confmatrix(plot_name)
-        reporter.print_results()
+        self.util.debug(f"plotting conf matrix as {plot_name}")
+        report.plot_confmatrix(plot_name, epoch=report.epoch)
+        report.print_results(report.epoch, file_name=plot_name)
+        report.print_probabilities(file_name=plot_name)
 
     def load_model(self, report):
         """Load a model from disk for a specific run and epoch and evaluate it.
