@@ -1,35 +1,49 @@
-# segment.py
-# segment data splits
+"""Segments the samples in the dataset into chunks based on voice activity detection using SILERO VAD [1].
+
+The segmentation results are saved to a file, and the distributions of the original and
+segmented durations are plotted.
+
+The module also handles configuration options, such as the segmentation method and sample
+selection, and reports the segmentation results.
+
+Usage:
+    python3 -m nkululeko.segment [--config CONFIG_FILE]
+
+Example:
+    nkululeko.segment --config tests/exp_androids_segment.ini
+
+References:
+    [1] https://github.com/snakers4/silero-vad
+    [2] https://github.com/pyannote/pyannote-audio
+"""
 
 import argparse
-import os
-import pandas as pd
 import configparser
-from nkululeko.experiment import Experiment
-from nkululeko.utils.util import Util
+import os
+
+import pandas as pd
+
+import audformat
+
 from nkululeko.constants import VERSION
+from nkululeko.experiment import Experiment
 import nkululeko.glob_conf as glob_conf
 from nkululeko.reporting.report_item import ReportItem
+from nkululeko.utils.util import Util
 
 
-def main(src_dir):
+def main():
     parser = argparse.ArgumentParser(description="Call the nkululeko framework.")
     parser.add_argument("--config", default="exp.ini", help="The base configuration")
     args = parser.parse_args()
-    if args.config is not None:
-        config_file = args.config
-    else:
-        config_file = f"{src_dir}/exp.ini"
+    config_file = args.config if args.config is not None else "exp.ini"
 
-    # test if the configuration file exists
     if not os.path.isfile(config_file):
         print(f"ERROR: no such file: {config_file}")
         exit()
 
-    # load one configuration per experiment
     config = configparser.ConfigParser()
     config.read(config_file)
-    # create a new experiment
     expr = Experiment(config)
     module = "segment"
     expr.set_module(module)
@@ -48,10 +62,15 @@ def main(src_dir):
     expr.fill_train_and_tests()
     util.debug(f"train shape : {expr.df_train.shape}, test shape:{expr.df_test.shape}")
 
+    def calc_dur(x):
+        starts = x[1]
+        ends = x[2]
+        return (ends - starts).total_seconds()
+
     # segment
     segmented_file = util.config_val("SEGMENT", "result", "segmented.csv")
 
-    segmenter = util.config_val("SEGMENT", "method", "silero")
+    method = util.config_val("SEGMENT", "method", "silero")
     sample_selection = util.config_val("SEGMENT", "sample_selection", "all")
     if sample_selection == "all":
         df = pd.concat([expr.df_train, expr.df_test])
@@ -64,27 +83,44 @@ def main(src_dir):
             f"unknown segmentation selection specifier {sample_selection},"
             " should be [all | train | test]"
         )
-    util.debug(f"segmenting {sample_selection}: {df.shape[0]} samples with {segmenter}")
-    if segmenter == "silero":
-        from nkululeko.segmenting.seg_silero import Silero_segmenter
-
-        segmenter = Silero_segmenter()
-        df_seg = segmenter.segment_dataframe(df)
-
+    result_file = f"{expr.data_dir}/{segmented_file}"
+    if os.path.exists(result_file):
+        util.debug(f"reusing existing result file: {result_file}")
+        df_seg = audformat.utils.read_csv(result_file)
     else:
-        util.error(f"unkown segmenter: {segmenter}")
+        util.debug(
+            f"segmenting {sample_selection}: {df.shape[0]} samples with {method}"
+        )
+        if method == "silero":
+            from nkululeko.segmenting.seg_silero import Silero_segmenter
 
-    def calc_dur(x):
-        from datetime import datetime
+            segmenter = Silero_segmenter()
+            df_seg = segmenter.segment_dataframe(df)
+        elif method == "pyannote":
+            from nkululeko.segmenting.seg_pyannote import Pyannote_segmenter
 
-        starts = x[1]
-        ends = x[2]
-        return (ends - starts).total_seconds()
+            segmenter = Pyannote_segmenter(config)
+            df_seg = segmenter.segment_dataframe(df)
+        else:
+            util.error(f"unknown segmenter: {method}")
+        # remove encoded labels
+        target = util.config_val("DATA", "target", None)
+        if "class_label" in df_seg.columns:
+            df_seg = df_seg.drop(columns=[target])
+            df_seg = df_seg.rename(columns={"class_label": target})
+        # save file
+        df_seg["duration"] = df_seg.index.to_series().map(lambda x: calc_dur(x))
+        df_seg.to_csv(f"{expr.data_dir}/{segmented_file}")
 
     if "duration" not in df.columns:
         df["duration"] = df.index.to_series().map(lambda x: calc_dur(x))
     num_before = df.shape[0]
     num_after = df_seg.shape[0]
+    util.debug(
+        f"saved {segmented_file} to {expr.data_dir}, {num_after} samples (was"
+        f" {num_before})"
+    )
+
     # plot distributions
     from nkululeko.plots import Plots
 
@@ -95,20 +131,10 @@ def main(src_dir):
     plots.plot_durations(
         df_seg, "segmented_durations", sample_selection, caption="Segmented durations"
     )
-    print("")
-    # remove encoded labels
-    target = util.config_val("DATA", "target", "emotion")
-    if "class_label" in df_seg.columns:
-        df_seg = df_seg.drop(columns=[target])
-        df_seg = df_seg.rename(columns={"class_label": target})
-    # save file
-    # dataname = "_".join(expr.datasets.keys())
-    # name = f"{dataname}{segment_target}"
-    df_seg.to_csv(f"{expr.data_dir}/{segmented_file}")
-    util.debug(
-        f"saved {segmented_file} to {expr.data_dir}, {num_after} samples (was"
-        f" {num_before})"
-    )
+    if method == "pyannote":
+        util.debug(df_seg[["speaker", "duration"]].groupby(["speaker"]).sum())
+        plots.plot_speakers(df_seg, sample_selection)
+
     glob_conf.report.add_item(
         ReportItem(
             "Data",
@@ -120,37 +146,5 @@ def main(src_dir):
     print("DONE")
 
 
-def get_segmentation(file):
-    #    print(f'segmenting {file[0]}')
-    print(".", end="")
-    wav = read_audio(file[0], sampling_rate=SAMPLING_RATE)
-    speech_timestamps = get_speech_timestamps(
-        wav, vad_model, sampling_rate=SAMPLING_RATE
-    )
-    files, starts, ends = [], [], []
-    for entry in speech_timestamps:
-        start = float(entry["start"] / 1000.0)
-        end = float(entry["end"] / 1000.0)
-        files.append(file[0])
-        starts.append(start)
-        ends.append(end)
-    seg_index = segmented_index(files, starts, ends)
-    return seg_index
-
-
-def segment_dataframe(df):
-    dfs = []
-    for file, values in df.iterrows():
-        index = get_segmentation(file)
-        dfs.append(
-            pd.DataFrame(
-                values.to_dict(),
-                index,
-            )
-        )
-    return audformat.utils.concat(dfs)
-
-
 if __name__ == "__main__":
-    cwd = os.path.dirname(os.path.abspath(__file__))
-    main(cwd)  # use this if you want to state the config file path on command line
+    main()  # use this if you want to state the config file path on command line
